Date: 01 4, 2002 1:42:03 PM

# renamenode

## Purpose

Rename a node's name oldName or the numth node number in a phrase aPhrase with a new name newName.

## Syntax

None = renamenode(aPhrase, oldName, newName)

aPhrase - type: phrase
oldName - type: str
newName - type: str

None - renamenode(aPhrase, number, newName)

aPhrase - type: phrase
number - type: int
newName - type: str

## Returns

## Remarks

## Example

## See Also

Knowledge Base Functions